@@ -19,11 +19,14 @@ class MyForm(QtGui.QMainWindow):
                 QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.playFart)
                 
                 self.farts={
-                        "One Day":"/opt/Simpsons/sounds/1.wav", "20 Dollor":"/opt/Simpsons/sounds/2.wav",
-                        "Blackhole":"/opt/Simpsons/sounds/3.wav", "Brain":"/opt/Simpsons/sounds/4.wav",
-                        "Candy":"/opt/Simpsons/sounds/5.wav", "No Tv":"/opt/Simpsons/sounds/6.wav", "Da Da Da Da":"/opt/Simpsons/sounds/7.wav"
-						, "Evil Homer":"/opt/Simpsons/sounds/8.wav", "Free":"/opt/Simpsons/sounds/9.wav", "Crap":"/opt/Simpsons/sounds/10.wav"
-						, "Mr Burns":"/opt/Simpsons/sounds/11.wav", "Smart":"/opt/Simpsons/sounds/12.wav"
+                        "One Day":"/opt/Simpsons/sounds/a.wav", "Dollor":"/opt/Simpsons/sounds/b.wav",
+                        "Blackhole":"/opt/Simpsons/sounds/c.wav", "Brain":"/opt/Simpsons/sounds/d.wav",
+                        "Candy":"/opt/Simpsons/sounds/e.wav", "No Tv":"/opt/Simpsons/sounds/f.wav", 
+                        "Da Da Da Da":"/opt/Simpsons/sounds/g.wav", "Evil Homer":"/opt/Simpsons/sounds/h.wav", 
+                        "Free":"/opt/Simpsons/sounds/i.wav", "Crap":"/opt/Simpsons/sounds/j.wav",
+			   "Mr Burns":"/opt/Simpsons/sounds/k.wav", "Smart":"/opt/Simpsons/sounds/l.wav",
+                        "Ohcrap":"/opt/Simpsons/sounds/m.wav", "Whisky":"/opt/Simpsons/sounds/n.wav", 
+                        "WooHo":"/opt/Simpsons/sounds/o.wav"
                         }
                 
         def playFart(self):
